@@ -1,4 +1,4 @@
-user_messages <- 'boxPlus(
+user_messages <- 'box(
   width = 12,
   title = "Box with messages",
   solidheader = TRUE,
@@ -9,16 +9,16 @@ user_messages <- 'boxPlus(
     userMessage(
       author = "Alexander Pierce",
       date = "20 Jan 2:00 pm",
-      src = "https://adminlte.io/themes/AdminLTE/dist/img/user1-128x128.jpg",
-      side = NULL,
+      image = "https://adminlte.io/themes/AdminLTE/dist/img/user1-128x128.jpg",
+      type = "received",
       "Is this template really for free? That iss unbelievable!"
     ),
     userMessage(
       author = "Sarah Bullock",
       date = "23 Jan 2:05 pm",
-      src = "https://adminlte.io/themes/AdminLTE/dist/img/user3-128x128.jpg",
-      side = "right",
+      image = "https://adminlte.io/themes/AdminLTE/dist/img/user3-128x128.jpg",
+      type = "sent",
       "You better believe it!"
     )
   )
-)'
\ No newline at end of file
+)'
